==> thux.price-1.0.0.tar.gz: thux.price-1.0.0/thux/price/models.py <==
# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.formats import number_format

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel

from thux.product.models import Product
from thux.organization.models import Organization
from thux.currency.models import Currency
from thux.vat.models import Vat
from thux.price import managers


class PriceList(DateModel, UserModel, StatusModel, OrderedModel):
    COST_PRICE = settings.PRICE_PRICE_LIST_COST_PRICE
    RESERVED_PRICE = settings.PRICE_PRICE_LIST_RESERVED_PRICE
    STREET_PRICE = settings.PRICE_PRICE_LIST_STREET_PRICE

    code = models.CharField(
        primary_key=True,
        max_length=15,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        db_index=True,
        max_length=255,
        verbose_name=_('slug'),
    )
    date_begin = models.DateField(
        db_index=True,
        verbose_name=_('date begin'),
    )
    date_end = models.DateField(
        db_index=True,
        verbose_name=_('date end'),
    )
    currency = models.ForeignKey(
        Currency,
        related_name='price_lists',
        verbose_name=_('currency'),
    )
    price_list_type = models.CharField(
        choices=settings.PRICE_PRICE_LIST_TYPE,
        max_length=2,
        verbose_name=_('price list type'),
    )

    objects = managers.PriceListManager()

    class Meta:
        verbose_name = _('price list')
        verbose_name_plural = _('price lists')
        ordering = ('ordering',)

    def __unicode__(self):
        return u'{} {}'.format(self.code, self.name)


class PriceListItem(DateModel, UserModel, StatusModel, OrderedModel):
    price_list = models.ForeignKey(
        PriceList,
        related_name='prices',
        verbose_name=_('price list'),
    )
    product = models.ForeignKey(
        Product,
        related_name='prices',
        verbose_name=_('product'),
    )
    price = models.DecimalField(
        max_digits=11,
        decimal_places=4,
        default=0,
        verbose_name=_('price'),
    )
    vat = models.ForeignKey(
        Vat,
        related_name='prices',
        verbose_name=_('vat'),
    )
    price_tax_included = models.BooleanField(
        default=True,
        verbose_name=_('price tax included'),
    )
    discount1 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 1 %')
    )
    discount2 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 2 %'),
    )
    recharge = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('recharge %'),
    )
    min_quantity = models.IntegerField(
        blank=True, null=True,
        verbose_name=_('min quantity'),
    )
    max_quantity = models.IntegerField(
        blank=True, null=True,
        verbose_name=_('max quantity'),
    )
    note = models.TextField(
        blank=True,
        verbose_name=_('note'),
    )

    objects = managers.PriceListItemManager()

    class Meta:
        verbose_name = _('price')
        verbose_name_plural = _('prices')
        ordering = ('ordering',)

    def __unicode__(self):
        return u'{} - {}: {}'.format(
            self.price_list.name, self.product.name,
            self.price
        )

    def get_date_begin(self):
        return self.price_list.date_begin
    get_date_begin.short_description = _('date begin')

    def get_date_end(self):
        return self.price_list.date_end
    get_date_end.short_description = _('date end')

    def get_price_vat_included(self):
        if self.price_tax_included:
            return self.price
        return self.price * (1 + self.product.vat.aliquot_perc / 100)
    price_vat_included = property(get_price_vat_included)

    def get_price_vat_excluded(self):
        if self.price_tax_included:
            return self.price / (1 + self.product.vat.aliquot_perc / 100)
        return self.price
    price_vat_excluded = property(get_price_vat_excluded)

    def get_price(self):
        last_price = (
            (self.price_vat_excluded * (1 - self.discount1)) *
            (1 - self.discount1)
        ) * (1 + self.recharge / 100)
        return last_price


class OrganizationPriceList(DateModel, UserModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        Organization,
        related_name='price_lists',
        verbose_name=_('organization'),
    )
    price_list = models.ForeignKey(
        PriceList,
        related_name='organization_price_lists',
        verbose_name=_('price list'),
    )
    discount1 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 1 %'),
    )
    discount2 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 2 %'),
    )
    recharge = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('recharge %'),
    )

    class Meta:
        verbose_name = _('organization price list')
        verbose_name_plural = _('organization price lists')
        ordering = ('ordering',)
        unique_together = (('price_list', 'organization',),)

    def __unicode__(self):
        return u'{} {}% + {}%' % (
            self.price_list.name,
            number_format(self.discount1, 1),
            number_format(self.discount2, 1)
        )

==> thux.price-2.0.2.tar.gz: thux.price-2.0.2/thux/price/models.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.formats import number_format

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel

from thux.product.models import Product
from thux.organization.models import Organization
from thux.currency.models import Currency
from thux.vat.models import Vat
from thux.price import managers


@python_2_unicode_compatible
class PriceList(DateModel, UserModel, StatusModel, OrderedModel):
    COST_PRICE = settings.PRICE_PRICE_LIST_COST_PRICE
    RESERVED_PRICE = settings.PRICE_PRICE_LIST_RESERVED_PRICE
    STREET_PRICE = settings.PRICE_PRICE_LIST_STREET_PRICE

    code = models.CharField(
        primary_key=True,
        max_length=15,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        db_index=True,
        max_length=255,
        verbose_name=_('slug'),
    )
    date_begin = models.DateField(
        db_index=True,
        verbose_name=_('date begin'),
    )
    date_end = models.DateField(
        db_index=True,
        verbose_name=_('date end'),
    )
    currency = models.ForeignKey(
        Currency,
        related_name='price_lists',
        verbose_name=_('currency'),
    )
    price_list_type = models.CharField(
        choices=settings.PRICE_PRICE_LIST_TYPE,
        max_length=2,
        verbose_name=_('price list type'),
    )

    objects = managers.PriceListManager()

    class Meta:
        verbose_name = _('price list')
        verbose_name_plural = _('price lists')
        ordering = ('ordering', '-date_begin')
        permissions = (
            ("list_pricelist", "Can list price list"),
            ("detail_pricelist", "Can detail price list"),
            ("disable_pricelist", "Can disable price list"),
        )

    def __str__(self):
        return '{} {}'.format(self.code, self.name)


@python_2_unicode_compatible
class PriceListItem(DateModel, UserModel, StatusModel, OrderedModel):
    price_list = models.ForeignKey(
        PriceList,
        related_name='prices',
        verbose_name=_('price list'),
    )
    product = models.ForeignKey(
        Product,
        related_name='prices',
        verbose_name=_('product'),
    )
    price = models.DecimalField(
        max_digits=11,
        decimal_places=4,
        default=0,
        verbose_name=_('price'),
    )
    vat = models.ForeignKey(
        Vat,
        related_name='prices',
        verbose_name=_('vat'),
    )
    price_tax_included = models.BooleanField(
        default=True,
        verbose_name=_('price tax included'),
    )
    discount1 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 1 %')
    )
    discount2 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 2 %'),
    )
    recharge = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('recharge %'),
    )
    min_quantity = models.IntegerField(
        blank=True, null=True,
        verbose_name=_('min quantity'),
    )
    max_quantity = models.IntegerField(
        blank=True, null=True,
        verbose_name=_('max quantity'),
    )
    note = models.TextField(
        blank=True,
        verbose_name=_('note'),
    )

    objects = managers.PriceListItemManager()

    class Meta:
        verbose_name = _('price')
        verbose_name_plural = _('prices')
        ordering = ('ordering',)
        permissions = (
            ("list_pricelistitem", "Can list price list item"),
            ("detail_pricelistitem", "Can detail price list item"),
            ("disable_pricelistitem", "Can disable price list item"),
        )

    def __str__(self):
        return '{} - {}: {}'.format(
            self.price_list.name, self.product.name,
            self.price
        )

    def get_date_begin(self):
        return self.price_list.date_begin
    get_date_begin.short_description = _('date begin')

    def get_date_end(self):
        return self.price_list.date_end
    get_date_end.short_description = _('date end')

    def get_price_vat_included(self):
        if self.price_tax_included:
            return self.price
        return self.price * (1 + self.product.vat.aliquot_perc / 100)
    price_vat_included = property(get_price_vat_included)

    def get_price_vat_excluded(self):
        if self.price_tax_included:
            return self.price / (1 + self.product.vat.aliquot_perc / 100)
        return self.price
    price_vat_excluded = property(get_price_vat_excluded)

    def get_price(self):
        last_price = (
            (self.price_vat_excluded * (1 - self.discount1)) *
            (1 - self.discount1)
        ) * (1 + self.recharge / 100)
        return last_price


@python_2_unicode_compatible
class OrganizationPriceList(DateModel, UserModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        Organization,
        related_name='price_lists',
        verbose_name=_('organization'),
    )
    price_list = models.ForeignKey(
        PriceList,
        related_name='organization_price_lists',
        verbose_name=_('price list'),
    )
    discount1 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 1 %'),
    )
    discount2 = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('discount 2 %'),
    )
    recharge = models.DecimalField(
        max_digits=5,
        decimal_places=2,
        default=0,
        verbose_name=_('recharge %'),
    )

    class Meta:
        verbose_name = _('organization price list')
        verbose_name_plural = _('organization price lists')
        ordering = ('ordering',)
        unique_together = (('price_list', 'organization',),)
        permissions = (
            ("list_organizationpricelist", "Can list organization price list"),
            ("detail_organizationpricelist", "Can detail organization price list"),
            ("disable_organizationpricelist", "Can disable organization price list"),
        )

    def __str__(self):
        return '{} {}% + {}%'.format(
            self.price_list.name,
            number_format(self.discount1, 1),
            number_format(self.discount2, 1)
        )
